library(stringr)
library(ggplot2)
library(gridExtra)
library(lubridate)
library(dplyr)
library(mgcv) #gam
######################################################################################
death_cert<-read.csv("/datos/THESIS: Hurricane Maria/Mortality Data P.R/death_cert.csv")
death_cert$X <- NULL ### Elimina la columna enumerada 

DATOS <- data.frame(year=death_cert$year, month=death_cert$month, day=death_cert$day,   date=as.character(death_cert$date), 
                    pop1=death_cert$pop, rate1=death_cert$rate, pop2=death_cert$pop2, rate2=death_cert$rate2, deaths=death_cert$deaths,
                    sepsis=death_cert$Sepsis, diabetes=death_cert$Diabetes, alzhaparki=death_cert$AlzheParki, neumonia=death_cert$Pneumo, 
                    cancer=death_cert$cancer, respiratorio=death_cert$respira, corazon=death_cert$corazon, cerebro=death_cert$cerebro,  
                    suicidio=death_cert$suici, caida=death_cert$caida, transp=death_cert$trans, homicidio=death_cert$homici, a_otros=death_cert$others)

death_new<-apply(DATOS[,10:22], 1, as.vector)  ### Realizar suma acumalada por dias
g<-data.frame(death_new)
####### convertir g en un vector
x=NULL
y=NULL
for (i in 1:1826) {
  x= c(y, g[,i] )
  y = x
}
####################################################################################  
DATOS<-DATOS[rep(seq_len(nrow(DATOS)), each=13),] ##### Cada celda de death_cert_new se multiplica por las 13 Enfermedades 
dim(DATOS)  ##23738  22

Enfermedades<-c("sepsis","diabetes","alzhaparki","neumonia","cancer","respiratorio","corazon","cerebro","suicidio","caida","transp","homicidio","a_otros")
causa<-as.factor(rep(Enfermedades,1826))
DATOS <- data.frame(DATOS,causa)

####################################################################################
DATOS$deaths=y
################## Generar la matriz de ceros y unos
t<-rbind(rep(diag(1,13,13),1826))
enf<-matrix(t,23738,13,byrow = TRUE)
DATOS[,10:22]=enf    #### reemplazar la matriz de cero y unos denntro del data.frame
###################################################################################
dn<-1:nrow(DATOS) #index of time
msep<-ifelse(DATOS$year==2017 & DATOS$month==9 & DATOS$day>=20,1,0) #after maria september indicator, not sum(ms)=11 as it should
moct<-ifelse(DATOS$year==2017 & DATOS$month==10,1,0)
mnov<-ifelse(DATOS$year==2017 & DATOS$month==11,1,0)
mdic<-ifelse(DATOS$year==2017 & DATOS$month==12,1,0)
mene<-ifelse(DATOS$year==2018 & DATOS$month==1,1,0)
mfeb<-ifelse(DATOS$year==2018 & DATOS$month==2,1,0)
mmar<-ifelse(DATOS$year==2018 & DATOS$month==3,1,0)
##################################################################################
lpop1<-log(DATOS$pop1)
lpop2<-log(DATOS$pop2)
#Time<-(dn - min(dn))/(max(dn) - min(dn))
doy1<-c(rep(1:365, each = 13),rep(1:365, each = 13),rep(1:366, each = 13),rep(1:365, each = 13),rep(1:365, each = 13))
#################################################################
##### Modelo ensayo 1::: family=quasipoisson
yr1<-as.factor(DATOS$year)
fit_model1<- gam(deaths ~ s(doy1,k=8,bs="cc") + msep + moct + mnov + mdic + mene + mfeb + mmar 
                 + causa + yr1, offset=lpop1, family=quasipoisson, method="REML", data=DATOS, select=T)

out <- summary(fit_model1)
exp(out$p.coeff[2:20]-1.96*out$se[2:20])
exp(out$p.coeff[2:20]+1.96*out$se[2:20])
exp(coef(fit_model1)[2:20])

resid.ssq <- sum(residuals(fit_model1,type="pearson")^2)  ## sum of squares of Pearson resids
resid.df <- nrow(DATOS)-length(coef(fit_model1))        ## estimated resid df (N-p)
resid.ssq/resid.df
anova(fit_model1)


resid.ssq <- sum(residuals(fit_n,type="pearson")^2)  ## sum of squares of Pearson resids
resid.df <- nrow(ny)-length(coef(fit_n))        ## estimated resid df (N-p)
resid.ssq/resid.df  # si es bien >1 tienes sobre dispersión



#acf(residuals(fit_model1,type="pearson"))
#pacf(residuals(fit_model1,type="pearson"))
#plot(fit_model1,all.terms=T)
#gam.check(fit_model1) #k is fine
#cor(DATOS$rate1,fit_model1$fitted.values)^2 

#### Una mirada rápida al ajuste del modelo, versus cómo se vería el modelo si no hubiera ocurrido HM
##### CUMULATIVE EXCESS DEATHS
who1<-which(as.character(DATOS$date)>=ymd("2017-09-20") & as.character(DATOS$date)<=ymd("2018-03-31"))
doys1<-doy1[who1]
mss1<-msep[who1]
mos1<-moct[who1]
mns1<-mnov[who1]
mds1<-mdic[who1]
mes1<-mene[who1]
mfs1<-mfeb[who1]
mms1<-mmar[who1]
yrs1<-yr1[who1]
causa1 <- causa[who1]
pds1<-data.frame(doy1=doys1,msep=mss1,moct=mos1,mnov=mns1,mdic=mds1,mene=mes1,mfeb=mfs1,mmar=mms1,causa=causa1,yr1=yrs1)
ilink1 <- family(fit_model1)$linkinv
Zps1 <- exp(lpop1[who1])*ilink1(predict(fit_model1,pds1)) #contrast total cumsum(Zps)[103]to sum(fitted(fit_n)[(994):(994+102)])
#(fitted(fit_model1)[(17655):(17655+2508)]) #20163

pds11 <- data.frame(doy1=doys1, msep=rep(0,length(who1)), moct=rep(0,length(who1)), mnov=rep(0,length(who1)), mdic=rep(0,length(who1)),
                     mene=rep(0,length(who1)), mfeb=rep(0,length(who1)), mmar=rep(0,length(who1)), causa=causa1, yr1=yrs1) #Hurricane Maria never happened conditions
Zps11 <- exp(lpop1[who1])*ilink1(predict(fit_model1,pds11)) #predicted daily deaths if HM never happened #changed to account for displacement (replaced lpop2)
all_excs1<-Zps1-Zps11

#cumulative for each month
sum(all_excs1[1:143])      #sep
sum(all_excs1[144:546])    #oct
sum(all_excs1[547:936])   #nov
sum(all_excs1[937:1339])  #dic
sum(all_excs1[1340:1742])  #ene
sum(all_excs1[1743:2106])  #feb
sum(all_excs1[2107:2509])  #mar

#cumulative end of month
sum(all_excs1[1:143])    #sep
sum(all_excs1[1:546])    #oct
sum(all_excs1[1:936])   #nov
sum(all_excs1[1:1339])   #dic
sum(all_excs1[1:1742])   #ene
sum(all_excs1[1:2106])   #feb
sum(all_excs1[1:2509])   #mar
total_exc_c1<-cumsum(all_excs1)
#############

##### Cumulative CIs
who11 <- which(as.character(DATOS$date) >=ymd("2017-09-20"))
pds111 <- data.frame(doy1=doy1,msep=msep,moct=moct,mnov=mnov,mdic=mdic,mene=mene,mfeb=mfeb,mmar=mmar,causa=causa,yr1=yr1)
Zps111 <- predict(fit_model1,pds111,type="lpmatrix") ## map coefs to fitted curves
n=10000   #bringing up to 100000 change CIs little from 10000 but not too long to run
pds1111 <- data.frame(doy1=doy1,msep=rep(0,length(n)),moct=rep(0,length(n)),mnov=rep(0,length(n)),mdic=rep(0,length(n)),
                   mene=rep(0,length(n)),mfeb=rep(0,length(n)),mmar=rep(0,length(n)),causa=causa,yr1=yr1)
Zps1111 <- predict(fit_model1,pds1111,type="lpmatrix") ## map coefs to fitted curves
pds111<-pds111[who11,]
pds1111<-pds1111[who11,]
Zps111<-Zps111[who11,]
Zps1111<-Zps1111[who11,]
spop1<-DATOS$pop1[who11]
spop2<-DATOS$pop2[who11]
gamma1 <- coef(fit_model1)
Vb1 <- vcov(fit_model1) ## posterior mean and cov of coefs

library(MASS) #mvnorm
set.seed(944)

gr1 <- mvrnorm(n,gamma1,Vb1) ## simulate n rep coef vectors from post.
a.range1 <- matrix(NA,n,nrow(Zps1111))
cum11 <- rep(NA, n)
cum21 <- rep(NA, n)
cum31 <- rep(NA, n)
cum41 <- rep(NA, n)
cum51 <- rep(NA, n)
cum61 <- rep(NA, n)
cum71 <- rep(NA, n)
ilink1 <- family(fit_model1)$linkinv
for (i in 1:n) { ## loop to get diff for each sim
  pred.a <-  spop1*ilink1(Zps111%*%gr1[i,])  ## curve for this replicate
  pred.a2 <- spop1*ilink1(Zps1111%*%gr1[i,]) #Ignore spop2, because otherwise excess will always be declining as pop decreases (too strong an assumption)
  a.range1[i,] <- pred.a-pred.a2 ## range for this curve
  cum11[i]<-sum(pred.a[1:143])-sum(pred.a2[1:143])
  cum21[i]<-sum(pred.a[1:546])-sum(pred.a2[1:546])
  cum31[i]<-sum(pred.a[1:936])-sum(pred.a2[1:936])
  cum41[i]<-sum(pred.a[1:1339])-sum(pred.a2[1:1339])
  cum51[i]<-sum(pred.a[1:1742])-sum(pred.a2[1:1742])
  cum61[i]<-sum(pred.a[1:2106])-sum(pred.a2[1:2106])
  cum71[i]<-sum(pred.a[1:2509])-sum(pred.a2[1:2509])
}

excess11<-apply(a.range1, 2,quantile,probs=c(0.025,.975) )
ci11 <- quantile(cum11, c(.025,.975)) #CI of excess deaths until 9/30
ci21 <- quantile(cum21, c(.025,.975))#CI of excess deaths until 10/31
ci31 <- quantile(cum31, c(.025,.975))#CI of excess deaths until 11/30
ci41 <- quantile(cum41, c(.025,.975))#CI of excess deaths until 12/31
ci51 <- quantile(cum51, c(.025,.975)) #CI of excess deaths until 01/31
ci61 <- quantile(cum61, c(.025,.975))#CI of excess deaths until 02/28
ci71 <- quantile(cum71, c(.025,.975))#CI of excess deaths until 03/31

######Grafica de Sepsis
whosepsis <- which(DATOS$causa=="sepsis")
DATOSsepsis= DATOS[whosepsis,]
seqsepsis= seq(1,2509, 13)

DATOSsepsis <- transform(DATOSsepsis, date = as.character(date))
sapply(DATOSsepsis, mode)

DATOSsepsis<-DATOSsepsis%>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

psepsis=DATOSsepsis %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqsepsis]), 
         u_cdf = cumsum(excess11[2,seqsepsis]),
         raw_cdf = cumsum(all_excs1[seqsepsis])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por Sepsis en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]

######Grafica de diabetes
whodiabetes <- which(DATOS$causa=="diabetes")
DATOSdiabetes= DATOS[whodiabetes,]
seqdiabetes= seq(2,2509, 13)

DATOSdiabetes <- transform(DATOSdiabetes, date = as.character(date))
sapply(DATOSdiabetes, mode)

DATOSdiabetes<-DATOSdiabetes%>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

pdiabetes=DATOSdiabetes %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqdiabetes]), 
         u_cdf = cumsum(excess11[2,seqdiabetes]),
         raw_cdf = cumsum(all_excs1[seqdiabetes])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por Diabetes en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]

######Grafica de alzheimer y parkinson
whoalzhaparki <- which(DATOS$causa=="alzhaparki")
DATOSalzhaparki= DATOS[whoalzhaparki,]
seqalzhaparki= seq(3,2509, 13)

DATOSalzhaparki <- transform(DATOSalzhaparki, date = as.character(date))
sapply(DATOSalzhaparki, mode)

DATOSalzhaparki<-DATOSalzhaparki%>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

palzhaparki=DATOSalzhaparki %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqalzhaparki]), 
         u_cdf = cumsum(excess11[2,seqalzhaparki]),
         raw_cdf = cumsum(all_excs1[seqalzhaparki])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por Alzheimer y Parkinson en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]

######Grafica de neumonía
whoneumonia <- which(DATOS$causa=="neumonia")
DATOSneumonia= DATOS[whoneumonia,]
seqneumonia= seq(4,2509, 13)

DATOSneumonia <- transform(DATOSneumonia, date = as.character(date))
sapply(DATOSneumonia, mode)

DATOSneumonia<-DATOSneumonia%>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

pneumonia=DATOSneumonia %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqneumonia]), 
         u_cdf = cumsum(excess11[2,seqneumonia]),
         raw_cdf = cumsum(all_excs1[seqneumonia])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por Neumonía en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]

######Grafica de cancer
whocancer <- which(DATOS$causa=="cancer")
DATOScancer= DATOS[whocancer,]
seqcancer= seq(5,2509, 13)

DATOS <- transform(DATOScancer, date = as.character(date))
sapply(DATOScancer, mode)

DATOScancer <-DATOScancer %>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

pcancer=DATOScancer %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqcancer]), 
         u_cdf = cumsum(excess11[2,seqcancer]),
         raw_cdf = cumsum(all_excs1[seqcancer])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por Cáncer en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]

######Grafica de respiratorio
whorespiratorio <- which(DATOS$causa=="respiratorio")
DATOSrespiratorio= DATOS[whorespiratorio,]
seqrespiratorio= seq(6,2509, 13)

DATOS <- transform(DATOSrespiratorio, date = as.character(date))
sapply(DATOSrespiratorio, mode)

DATOSrespiratorio <-DATOSrespiratorio%>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

prespiratorio=DATOSrespiratorio %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqrespiratorio]), 
         u_cdf = cumsum(excess11[2,seqrespiratorio]),
         raw_cdf = cumsum(all_excs1[seqrespiratorio])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por Enfermedades Respiratorias en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]

######Grafica de corazón
whocorazon <- which(DATOS$causa=="corazon")
DATOScorazon= DATOS[whocorazon,]
seqcorazon= seq(7,2509, 13)

DATOS <- transform(DATOScorazon, date = as.character(date))
sapply(DATOScorazon, mode)

DATOScorazon <-DATOScorazon %>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

pcorazon=DATOScorazon %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqcorazon]), 
         u_cdf = cumsum(excess11[2,seqcorazon]),
         raw_cdf = cumsum(all_excs1[seqcorazon])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por corazón en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]

######Grafica de cerebro
whocerebro <- which(DATOS$causa=="cerebro")
DATOScerebro= DATOS[whocerebro,]
seqcerebro= seq(8,2509, 13)

DATOS <- transform(DATOScerebro, date = as.character(date))
sapply(DATOScerebro, mode)

DATOScerebro <-DATOScerebro %>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

pcerebro=DATOScerebro %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqcerebro]), 
         u_cdf = cumsum(excess11[2,seqcerebro]),
         raw_cdf = cumsum(all_excs1[seqcerebro])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por Cerebrovascular en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]

######Grafica de suicidio
whosuicidio <- which(DATOS$causa=="suicidio")
DATOSsuicidio= DATOS[whosuicidio,]
seqsuicidio = seq(9, 2509, 13)

DATOS <- transform(DATOSsuicidio, date = as.character(date))
sapply(DATOSsuicidio, mode)

DATOSsuicidio <-DATOSsuicidio %>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

psuicidio=DATOSsuicidio %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqsuicidio]), 
         u_cdf = cumsum(excess11[2,seqsuicidio]),
         raw_cdf = cumsum(all_excs1[seqsuicidio])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por Suicidio en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]

######Grafica de caida
whocaida <- which(DATOS$causa=="caida")
DATOScaida= DATOS[whocaida,]
seqcaida = seq(10, 2509, 13)

DATOS <- transform(DATOScaida, date = as.character(date))
sapply(DATOScaida, mode)

DATOScaida <-DATOScaida %>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

pcaida=DATOScaida %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqcaida]), 
         u_cdf = cumsum(excess11[2,seqcaida]),
         raw_cdf = cumsum(all_excs1[seqcaida])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por Caída en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]

######Grafica de transporte
whotransp <- which(DATOS$causa=="transp")
DATOStransp = DATOS[whotransp ,]
seqtransp  = seq(11, 2509, 13)

DATOS <- transform(DATOStransp , date = as.character(date))
sapply(DATOStransp , mode)

DATOStransp  <-DATOStransp  %>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

ptransp = DATOStransp  %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqtransp]), 
         u_cdf = cumsum(excess11[2,seqtransp]),
         raw_cdf = cumsum(all_excs1[seqtransp])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por Transporte en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]

######Grafica de homicidio
whohomicidio <- which(DATOS$causa=="homicidio")
DATOShomicidio = DATOS[whohomicidio,]
seqhomicidio = seq(12, 2509, 13)

DATOS <- transform(DATOShomicidio, date = as.character(date))
sapply(DATOShomicidio, mode)

DATOShomicidio <-DATOShomicidio %>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

phomicidio=DATOShomicidio %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqhomicidio]), 
         u_cdf = cumsum(excess11[2,seqhomicidio]),
         raw_cdf = cumsum(all_excs1[seqhomicidio])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por Homicidio en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]

######Grafica de otras causas
whootros <- which(DATOS$causa=="a_otros")
DATOSotros = DATOS[whootros,]
seqotros = seq(13, 2509, 13)

DATOS <- transform(DATOSotros, date = as.character(date))
sapply(DATOSotros, mode)

DATOSotros <-DATOSotros %>%mutate(date=seq(as.Date("2014/1/1"), as.Date("2018/12/31"), "days"))

potros=DATOSotros %>%
  filter(date >=ymd("2017-09-20") & date <=ymd("2018-03-31")) %>%
  mutate(l_cdf = cumsum(excess11[1,seqotros]), 
         u_cdf = cumsum(excess11[2,seqotros]),
         raw_cdf = cumsum(all_excs1[seqotros])) %>%
  ggplot() +
  geom_step(aes(date, l_cdf)) +
  geom_step(aes(date, u_cdf)) +
  geom_step(aes(date, raw_cdf),col="red") +
  scale_x_date(date_labels = "%b %y", date_breaks = "1 months") +
  theme(axis.text.x = element_text(angle = 90, hjust = 1)) + 
  #ggtitle("Excess deaths by date") + 
  ylab("Muertes por otras causas en exceso acumuladas") +xlab("")+
  geom_hline(yintercept = 64, lty=2, col="grey")
#cumulative_excess_deaths

l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]









######   ######
######   ######
plot.gam(fit_model51,col=1)  #k=13   #negro
grid(26, lty = 1, lwd = 1)
par(new=T)
plot.gam(fit_model51,col=2)  #k=17   #rojo  
par(new=T)
plot.gam(fit_model51,col=3)  #k=10   #Verde  
par(new=T)
plot.gam(fit_model51,col=4)  #k=17   #Azul
par(new=T)
plot.gam(fit_model51,col=6)  #k=18   #Rosado
par(new=T)
plot.gam(fit_model51,col=7)  #k=33   #Amarillo
par(new=T)
plot.gam(fit_model51,col=11)  #k=32   #

gam.check(fit_model2)

acf(residuals(fit_model2,type="pearson"),lag.max = 40, main="Serie residuales" )
pacf(residuals(fit_model2,type="pearson"),lag.max = 100, main="Serie residuales")

#Prueba para establecer que el modelo es estacionario 
Box.test(residuals(fit_model2,type="pearson"),lag=1, type="Ljung")




l_cdf[11]; u_cdf[11]  ; raw_cdf[11]
l_cdf[42]; u_cdf[42]  ; raw_cdf[42]
l_cdf[72]; u_cdf[72]  ; raw_cdf[72]
l_cdf[103]; u_cdf[103]; raw_cdf[103]
l_cdf[134]; u_cdf[134]; raw_cdf[134]
l_cdf[162]; u_cdf[162]; raw_cdf[162]
l_cdf[193]; u_cdf[193]; raw_cdf[193]




pn1 <- data.frame(doy=doy1,ms=rep(0,length(doy1)),mo=rep(0,length(doy1)),mn=rep(0,length(doy1)),
                  md=rep(0,length(doy1)),me=rep(0,length(doy1)),mf=rep(0,length(doy1)),
                  mm=rep(0,length(doy1)),yr=yr1)
ilink1 <- family(fit_model1)$linkinv
no_hm1 <- exp(lpop2)*ilink1(predict(fit_model1,pn1))
plot(DATOS$deaths)
lines(no_hm1,col="blue")
lines(fitted(fit_model1),col="red")

#approximate 95% point-wise CI
plot(fit_model1, shade = TRUE, seWithMean = TRUE, residuals = TRUE, pch = 16, cex = 0.8)
is.factor(DATOS$date)
#point-wise CIs
check1 <- DATOS%>%filter(as.character(date)>=ymd("2016-09-01"))
fits1<-fit_model1$fitted[(length(fit_model1$fitted)-(nrow(check1)-1)):length(fit_model1$fitted)]
ses1<-ilink1(predict(fit_model1,se=TRUE)$se)
ses1<-ses1[(length(fit_model1$fitted)-(nrow(check1)-1)):length(fit_model1$fitted)]
tmp1<- DATOS%>%filter(as.character(date)>=ymd("2016-09-01"))%>%mutate(fit = fits1,se_fit = ses1)
#############
#BETTER ALTERNATIVE
n=10000
who1<-which(as.character(DATOS$date)>=ymd("2016-09-01"))
pd1 <- data.frame(doy=doy1,ms=msep,mo=moct,mn=mnov,md=mdic,me=mene,mf=mfeb,mm=mmar,yr=yr1)
Zp1 <- predict(fit_model1,pd1,type="lpmatrix") ## map coefs to fitted curves
pd11<- data.frame(doy=doy1,ms=rep(0,length(n)),mo=rep(0,length(n)),mn=rep(0,length(n)),
                  md=rep(0,length(n)),me=rep(0,length(n)),mf=rep(0,length(n)),
                  mm=rep(0,length(n)),yr=yr1)
Zp11 <- predict(fit_model1,pd11,type="lpmatrix") ## map coefs to fitted curves
pd1<-pd1[who1,];pd11<-pd11[who1,]
Zp1<-Zp1[who1,];Zp11<-Zp11[who1,]
spop1<-DATOS$pop1[who1]
gamma <- coef(fit_model1);Vb <- vcov(fit_model1) ## posterior mean and cov of coefs

library(MASS) #mvnorm
set.seed(944)
gr1 <- mvrnorm(n,gamma,Vb) ## simulate n rep coef vectors from post.

pred.all1<-matrix(NA,n,nrow(Zp1))

for (i in 1:n) { ## loop to get diff for each sim
  pred.all1[i,] <- spop1*ilink1(Zp1%*%gr1[i,])  ## curve for this replicate
}

pred.all_ci1<-apply(pred.all1, 2,quantile,probs=c(0.025,.975) )





